@@ -372,6 +372,7 @@ def _write_hits(
     ):
     """Worker for writing."""
 
+    processed = 0
     peanut.output.print_sam_header(references, read_group)
     while True:
         item = bam_queue.get()
@@ -382,9 +383,11 @@ def _write_hits(
         queries, postprocessed_hits = item
         stats.start_timer("writing")
         peanut.output.print_sam(queries, postprocessed_hits, paired, references.names, use_xa, no_cigars=no_cigars)
+        processed += postprocessed_hits.window_size
         del postprocessed_hits
         stats.stop_timer("writing")
         bam_queue.task_done()
+        logging.info("written hits of {} queries".format(processed))
 
 
 def argument_parser():
@@ -438,8 +441,8 @@ def argument_parser():
     group.add_argument("--strata", "-s", default=1, metavar="N", help="How many strata (hits of the same quality) should be reported for each read (default: 1). Use --strata all to report all strata.")
     group.add_argument("--max-hits", "-m", type=int, default=100, metavar="N", help="Maximum number of hits per read (default 100). Regardless of strata value, this limits the number of records per read in the bam file.")
     group.add_argument("--accurate-mapq", action="store_true", help="Do not set all mapping qualities to zero if a read aligns ambiguously to multiple positions. The default behaviour ensures compatibility to downstream tools like GATK.")
-    group.add_argument("--insert-size", "--isize", type=int, default=220, metavar="I", help="Expected insert size for read and mate (default 220). See --insert-size-error for effects.")
-    group.add_argument("--insert-size-error", "--ierr", type=int, default=50, metavar="E", help="Maximum deviation from expected insert size (default 50). Insert sizes within [I-Em, I+E] will lead to read and mate being marked as properly paired.")
+    group.add_argument("--insert-size", "--isize", type=int, default=300, metavar="I", help="Expected insert size for read and mate (default 300). See --insert-size-error for effects.")
+    group.add_argument("--insert-size-error", "--ierr", type=int, default=300, metavar="E", help="Maximum deviation from expected insert size (default 300). Insert sizes within [I-Em, I+E] will lead to read and mate being marked as properly paired. Note: if this interval is improper for your data, it can lead to slowdowns because the rescue mode becomes active for unpaired reads.")
     group.add_argument("--gap-open-penalty", "-O", default=2, type=int, metavar="N", help="Gap open penalty (default 2).")
     group.add_argument("--gap-extend-penalty", "-E", default=1, type=int, metavar="N", help="Gap extend penalty (default 1).")
 
